#![feature(duration_constructors)]

mod config;
mod lastfm;
mod main_loop;
mod player;
mod track;

use crate::config::Config;
use crate::lastfm::get_scrobbler;
use anyhow::{Context, Result};
use envconfig::Envconfig;
use tracing::{debug, Level};

fn main() -> Result<()> {
    dotenvy::dotenv()?;
    tracing_subscriber::fmt()
        .with_max_level(if cfg!(debug_assertions) { Level::DEBUG } else { Level::INFO })
        .init();

    debug!("{} by {}, {}",
        env!("CARGO_PKG_NAME"),
        env!("CARGO_PKG_AUTHORS"),
        env!("CARGO_PKG_DESCRIPTION")
    );

    let config = Config::init_from_env()
        .context("failed to initiate configuration from .env")?;
    let scrobbler = get_scrobbler(&config)
        .context("failed to create scrobbler")?;

    main_loop::start(&config, scrobbler)?;

    Ok(())
}